@@ -48,6 +48,8 @@ private slots:
     void SaveConfig();
     void LoadVoice();
     void Browse();
+    void SaveXML();
+    void LogMessage(QByteArray msg);
     QString GetSound(QString distance, QString unit, QString linkID, QString maneuverType, QString turnVal);
 };
 
